@@ -9,7 +9,7 @@ use crate::{
     irust::format::{format_check_output, format_err, format_eval_output},
     utils::ctrlc_cancel,
 };
-use irust_repl::{cargo_cmds::*, EvalResult};
+use irust_repl::{cargo_cmds::*, EvalResult, Executor, ToolChain};
 use printer::printer::{PrintQueue, PrinterItem};
 
 const SUCCESS: &str = "Ok!";
@@ -58,6 +58,7 @@ impl IRust {
             cmd if cmd.starts_with(":time") => self.time(),
             cmd if cmd.starts_with(":bench") => self.bench(),
             cmd if cmd.starts_with(":asm") => self.asm(),
+            cmd if cmd.starts_with(":executor") => self.executor(),
             _ => self.parse_second_order(),
         }
     }
@@ -93,16 +94,17 @@ impl IRust {
     }
 
     fn toolchain(&mut self) -> Result<PrintQueue> {
-        let toolchain = ToolChain::from_str(
-            self.buffer
-                .to_string()
-                .split_whitespace()
-                .nth(1)
-                .unwrap_or("?"),
-        )?;
-        self.repl.set_toolchain(toolchain);
-        self.options.toolchain = toolchain;
-        success!()
+        let buffer = self.buffer.to_string();
+        let toolchain = buffer.split_whitespace().nth(1);
+
+        if let Some(toolchain) = toolchain {
+            let toolchain = ToolChain::from_str(toolchain)?;
+            self.repl.set_toolchain(toolchain);
+            self.options.toolchain = toolchain;
+            success!()
+        } else {
+            print_queue!(self.options.toolchain.to_string(), Color::Blue)
+        }
     }
 
     fn add_dep(&mut self) -> Result<PrintQueue> {
@@ -533,4 +535,18 @@ impl IRust {
 
         print_queue!(asm, self.options.eval_color)
     }
+
+    fn executor(&mut self) -> Result<PrintQueue> {
+        let buffer = self.buffer.to_string();
+        let executor = buffer.split_whitespace().nth(1);
+        if let Some(executor) = executor {
+            let executor = Executor::from_str(executor.trim())?;
+            self.repl.set_executor(executor)?;
+            // save executor
+            self.options.executor = executor;
+            success!()
+        } else {
+            print_queue!(self.options.executor.to_string(), Color::Blue)
+        }
+    }
 }
